@@ -13,16 +13,14 @@ from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.core.management.base import BaseCommand, CommandError
 from django.core.servers.basehttp import get_internal_wsgi_application
-from django.db import DEFAULT_DB_ALIAS, connections
 from django.db.backends import utils
-from django.db.migrations.executor import MigrationExecutor
-from django.utils.autoreload import gen_filenames
+try:
+    from django.utils.autoreload import gen_filenames
+except ImportError:  # Django >=2.2
+    from django.utils.autoreload import get_reloader
 
-from django_extensions.management.technical_response import \
-    null_technical_500_response
-from django_extensions.management.utils import (
-    RedirectHandler, has_ipdb, setup_logger, signalcommand,
-)
+    def gen_filenames():
+        return get_reloader().watched_files()
 
 try:
     if 'whitenoise.runserver_nostatic' in settings.INSTALLED_APPS:
@@ -38,6 +36,10 @@ try:
 except ImportError:
     USE_STATICFILES = False
 
+from django_extensions.management.technical_response import null_technical_500_response
+from django_extensions.management.utils import RedirectHandler, has_ipdb, setup_logger, signalcommand
+
+
 naiveip_re = re.compile(r"""^(?:
 (?P<addr>
     (?P<ipv4>\d{1,3}(?:\.\d{1,3}){3}) |         # IPv4 address
@@ -355,7 +357,7 @@ class Command(BaseCommand):
             webbrowser.open(bind_url)
 
         if use_reloader and settings.USE_I18N:
-            extra_files.extend(filter(lambda filename: filename.endswith('.mo'), gen_filenames()))
+            extra_files.extend(filter(lambda filename: str(filename).endswith('.mo'), gen_filenames()))
 
         # Werkzeug needs to be clued in its the main instance if running
         # without reloader or else it won't show key.
@@ -416,18 +418,6 @@ class Command(BaseCommand):
         key_file = cls._determine_path_for_file(options['key_file_path'], options['cert_path'], "key")
         return cert_file, key_file
 
-    if django.VERSION[:2] <= (1, 9):
-        def check_migrations(self):
-            """
-            Checks to see if the set of migrations on disk matches the
-            migrations in the database. Prints a warning if they don't match.
-            """
-            executor = MigrationExecutor(connections[DEFAULT_DB_ALIAS])
-            plan = executor.migration_plan(executor.loader.graph.leaf_nodes())
-            if plan and self.show_startup_messages:
-                self.stdout.write(self.style.NOTICE("\nYou have unapplied migrations; your app may not work properly until they are applied."))
-                self.stdout.write(self.style.NOTICE("Run 'python manage.py migrate' to apply them.\n"))
-
 
 def set_werkzeug_log_color():
     """Try to set color to the werkzeug log.
