@@ -80,9 +80,6 @@ class Command(BaseCommand):
 
     @signalcommand
     def handle(self, *args, **options):
-        if args:
-            appname, = args
-
         if options['no_color']:
             style = no_style()
         else:
